@@ -104,12 +104,12 @@ def get_knowledge_base(title: str):
     kb_from_title = {}
     for kb_id in knowledge_bases.keys():
         kb = knowledge_bases[kb_id] # get the KnowledgeBase object
-        title = kb.title
-        if title not in kb_from_title:
-            kb_from_title[title] = kb
+        if kb.title not in kb_from_title:
+            kb_from_title[kb.title] = kb
         else:
-            raise Exception('Duplicate knowledge base title: ' + title)
+            raise Exception('Duplicate knowledge base title: ' + kb.title)
     
+    # if the title we're looking for is in the map, return the KnowledgeBase object
     if title in kb_from_title:
         return kb_from_title[title]
     else:
