@@ -55,6 +55,7 @@ class Model:
         for instance in resp['body']:
             inst = ModelInstance(
                 ai_name=instance['ai_name'],
+                additional_knowledge_bases=instance['additional_knowledge_bases'],
                 model_id=instance['model_id'],
                 supp_id=instance['supp_id'],
                 description=instance['description'],
@@ -64,9 +65,9 @@ class Model:
         return instances
 
     # convenience method
-    def create_instance(self, ai_name: str = "AI", knowledge_bases: list = None):
+    def create_instance(self, ai_name: str = "AI", additional_knowledge_bases: list = None):
         # TODO: add support for passing in knowledge bases by name instead of id
-        instance_obj = ModelInstance(model_id=self.model_id, ai_name=ai_name, knowledge_bases=knowledge_bases)
+        instance_obj = ModelInstance(model_id=self.model_id, ai_name=ai_name, additional_knowledge_bases=additional_knowledge_bases)
         resp_body = instance_obj.create()
         return instance_obj
 
@@ -87,9 +88,9 @@ class Model:
 
 
 class ModelInstance:
-    def __init__(self, ai_name: str, knowledge_bases: list = None, model_id: str = None, supp_id: str = None, description: str = None, instance_id = None):
+    def __init__(self, ai_name: str, additional_knowledge_bases: list = None, model_id: str = None, supp_id: str = None, description: str = None, instance_id = None):
         self.ai_name = ai_name
-        self.knowledge_bases = knowledge_bases # list of knowledge base ids
+        self.additional_knowledge_bases = additional_knowledge_bases # list of knowledge base ids
         self.model_id = model_id
         self.supp_id = supp_id
         self.description = description
@@ -112,8 +113,8 @@ class ModelInstance:
             raise Exception('This model instance has already been deployed: ' + self.instance_id)
         url = BASE_URL + f'models/{self.model_id}/instances'
         payload = {'ai_name': self.ai_name}
-        if self.knowledge_bases is not None:
-            payload['knowledge_bases'] = self.knowledge_bases
+        if self.additional_knowledge_bases is not None:
+            payload['additional_knowledge_bases'] = self.additional_knowledge_bases
         if self.supp_id is not None:
             payload['supp_id'] = self.supp_id
         if self.description is not None:
@@ -128,8 +129,8 @@ class ModelInstance:
             raise Exception('This model instance has not been deployed yet. Please run `model_instance.create()` before running `model_instance.update()')
         url = BASE_URL + f'models/{self.model_id}/instances/{self.instance_id}'
         payload = {}
-        if self.knowledge_bases is not None:
-            payload['knowledge_bases'] = self.knowledge_bases
+        if self.additional_knowledge_bases is not None:
+            payload['additional_knowledge_bases'] = self.additional_knowledge_bases
         if self.supp_id is not None:
             payload['supp_id'] = self.supp_id
         if self.description is not None:
